--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- mapinfo.lua
--
local mapinfo = {
	name = "Cold_Koom v2.0",
	description = "By Beherith - mysterme@gmail.com, terrian/texture modified by Silver, Based On Koom Valley V2",
	author = "By Beherith - mysterme@gmail.com, terrian/texture modified by Silver",
	version = "2.0",
	mapfile = "maps/Cold_Koom.smf",
	modtype = 3, --// 1 = primary, 0 = hidden, 3 = map
	replace = {},
	maphardness = 100000,
	tidalStrength = 21,
	gravity = 115,
	maxMetal = 15,
	extractorRadius = 115,
	autoShowMetal = true,
	smf = {
		minheight = 5,
		maxheight = 700,
		smtFileName0 = "maps/Cold_Koom.smt"
	},
	resources = {
		detailTex = "detailtex.bmp"
	},
	splats = {
		TexScales = {0.012, 0.012, 0.012, 1},
		TexMults = {0.3, 0.3, 0.2, 0.1}
	},
	atmosphere = {
		minWind = 1.0,
		maxWind = 13.0,
		fogStart = 0.7,
		fogEnd = 1.0,
		fogColor = {0.80, 0.93, 1},
		sunColor = {1.0, 1.0, 1.0},
		skycolor = {0.76, 0.83, 1},
		skyDir = {0.0, 0.0, -1.0},
		skyBox = "",
		cloudDensity = 0.5,
		cloudColor = {1, 0.89, 0.7}
	},
	grass = {
		bladeWaveScale = 1.0,
		bladeWidth = 0.5,
		bladeHeight = 6.0,
		bladeAngle = 1.57,
		bladeColor = {0.59, 0.81, 0.57} --// does nothing when `grassBladeTex` is set
	},
	lighting = {
		--// dynsun
		sunStartAngle = 0.0,
		sunOrbitTime = 1440.0,
		sundir = {0.3, 0.656, -0.515},
		--// unit & ground lighting
		groundambientcolor = {0.8, 0.8, 0.85},
		grounddiffusecolor = {1.0, 0.9, 0.8},
		groundshadowdensity = 1.3,
		unitambientcolor = {0.5, 0.5, 0.5},
		unitdiffusecolor = {1.0, 0.9, 0.8},
		unitshadowdensity = 0.8,
		specularsuncolor = {0.6, 0.7, 0.9},
		specularExponent = 100.0
	},
	water = {
		damage = 0,
		repeatX = 0.0,
		repeatY = 0.0,
		absorb = {0.001, 0.001, 0.001},
		basecolor = {1, 1, 1},
		mincolor = {0.5, 0.5, 0.5},
		ambientFactor = 1.0,
		diffuseFactor = 1.0,
		specularFactor = 1.0,
		specularPower = 20.0,
		surfacecolor = {1, 0.89, 0.7},
		surfaceAlpha = 0.5,
		diffuseColor = {1.0, 1.0, 1.0},
		specularColor = {0.5, 0.5, 0.5},
		fresnelMin = 0.2,
		fresnelMax = 0.8,
		fresnelPower = 4.0,
		reflectionDistortion = 1.0,
		blurBase = 2.0,
		blurExponent = 1.5,
		perlinStartFreq = 8.0,
		perlinLacunarity = 3.0,
		perlinAmplitude = 0.9,
		windSpeed = 1.0, --// does nothing yet
		shoreWaves = true,
		forceRendering = false
	},
	teams = {
		[0] = {
			startPos = {
				x = 0,
				z = 0
			}
		},
		[1] = {
			startPos = {
				x = 0,
				z = 0
			}
		}
	},
	terrainTypes = {
		[0] = {
			name = "Default",
			hardness = 1.0,
			receiveTracks = true,
			moveSpeeds = {
				tank = 1.1,
				kbot = 1.0,
				hover = 1.0,
				ship = 1.0
			}
		}
	}
}
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Helper
local function lowerkeys(ta)
	local fix = {}

	for i, v in pairs(ta) do
		if (type(i) == "string") and (i ~= i:lower()) then
			fix[#fix + 1] = i
		end

		if (type(v) == "table") then
			lowerkeys(v)
		end
	end

	for i = 1, #fix do
		local idx = fix[i]
		ta[idx:lower()] = ta[idx]
		ta[idx] = nil
	end
end

lowerkeys(mapinfo)

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Map Options
if (Spring) then
	local function tmerge(t1, t2)
		for i, v in pairs(t2) do
			if (type(v) == "table") then
				t1[i] = t1[i] or {}
				tmerge(t1[i], v)
			else
				t1[i] = v
			end
		end
	end

	-- make code safe in unitsync
	if (not Spring.GetMapOptions) then
		Spring.GetMapOptions = function() return {} end
	end

	function tobool(val)
		local t = type(val)

		if (t == "nil") then
			return false
		elseif (t == "boolean") then
			return val
		elseif (t == "number") then
			return val ~= 0
		elseif (t == "string") then
			return (val ~= "0") and (val ~= "false")
		end

		return false
	end

	getfenv()["mapinfo"] = mapinfo
	local files = VFS.DirList("mapconfig/mapinfo/", "*.lua")
	table.sort(files)

	for i = 1, #files do
		local newcfg = VFS.Include(files[i])

		if newcfg then
			lowerkeys(newcfg)
			tmerge(mapinfo, newcfg)
		end
	end

	getfenv()["mapinfo"] = nil
end

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
return mapinfo
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------